"""Public config file for GitBase package"""
import os
import platform

def find_os_data_path():
    """Function to find internal data path based on OS type (e.g., Windows = C:/Users/[USER]/AppData/Roaming) and return it as a string."""
    system = platform.system()
    home = os.path.expanduser("~")

    if system == "Windows":
        path = os.path.join(home, "AppData", "Roaming")
    elif system == "Darwin":  # macOS
        path = os.path.join(home, "Library", "Application Support")
    else:  # Assume Linux/Unix
        path = os.path.join(home, ".local", "share")

    return path

class configClass:
    def __init__(self):
        self.app_name = "GitBase"
        self.publisher = "Taireru LLC"
        self.version = "1.0.0"
        self.show_logs = True
        self.use_offline = True
        self.use_version_path = True
        self.datpath = f"{find_os_data_path()}/{self.publisher}/{self.app_name}/{self.version}/data/gitbase/"
        
    def setdatpath(self):
        self.datpath = f"{find_os_data_path()}/{self.publisher}/{self.app_name}/{self.version}/data/gitbase/"
    
    @property
    def cleanpath(self) -> str:
        return f"{find_os_data_path()}/{self.publisher}/{self.app_name}/{self.version}" if self.use_version_path else f"{find_os_data_path()}/{self.publisher}/{self.app_name}"

config = configClass()